@@ -542,7 +542,7 @@ public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeR
                     if (medias.size() == 1 && mPlaylistAdapter.getMedias(position).get(0).getType() == MediaWrapper.TYPE_PLAYLIST) {
                         if (mMediaBrowser == null)
                             mMediaBrowser = new MediaBrowser(VLCInstance.get(), this);
-                        mMediaBrowser.browse(mPlaylistAdapter.getMedias(position).get(0).getUri(), true);
+                        mMediaBrowser.browse(mPlaylistAdapter.getMedias(position).get(0).getUri(), MediaBrowser.Flag.Interact);
                         return true;
                     }
             }
