@@ -110,10 +110,10 @@ public class FileBrowserFragment extends BaseBrowserFragment {
                     directory = new MediaWrapper(AndroidUtil.PathToUri(mediaDirLocation));
                     directory.setType(MediaWrapper.TYPE_DIR);
                     if (TextUtils.equals(AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY, mediaDirLocation))
-                        directory.setDisplayTitle(getString(R.string.internal_memory));
+                        directory.setDisplayTitle(VLCApplication.getAppResources().getString(R.string.internal_memory));
                     mAdapter.addItem(directory, false, false);
                 }
-                if (mReadyToDisplay) {
+                if (mReadyToDisplay && context != null) {
                     context.runOnUiThread(new Runnable() {
                         @Override
                         public void run() {
